@@ -1,7 +1,7 @@
 package Proc::Govern;
 
-our $DATE = '2019-04-30'; # DATE
-our $VERSION = '0.201'; # VERSION
+our $DATE = '2019-05-22'; # DATE
+our $VERSION = '0.202'; # VERSION
 
 use 5.010001;
 use strict;
@@ -111,7 +111,7 @@ _
         },
         pid_dir => {
             summary => 'Directory to put PID file in',
-            schema => 'str*',
+            schema => 'dirname*',
         },
         on_multiple_instance => {
             schema => ['str*' => in => ['exit']],
@@ -134,7 +134,7 @@ _
             tags => ['category:load-control'],
         },
         load_check_every => {
-            schema => [duration => default => 10],
+            schema => [duration => {default => 10, 'x.perl.coerce_rules'=>['str_human']}],
             summary => 'Frequency of load checking',
             tags => ['category:load-control'],
         },
@@ -224,7 +224,7 @@ _
             tags => ['category:output-control'],
         },
         timeout => {
-            schema => ['int*'],
+            schema => ['duration*', 'x.perl.coerce_rules'=>['str_human']],
             summary => 'Apply execution time limit, in seconds',
             description => <<'_',
 
@@ -246,7 +246,7 @@ _
         },
         # not yet defined
         #restart_delay => {
-        #    schema => ['duration*', default=>0],
+        #    schema => ['duration*', default=>0, 'x.perl.coerce_rules'=>['str_human']],
         #    tags => ['category:restart'],
         #},
         #check_alive => {
@@ -261,7 +261,7 @@ _
         },
         euid => {
             summary => 'Set EUID of command process',
-            schema => 'uint*',
+            schema => 'unix::uid*',
             description => <<'_',
 
 Need to be root to be able to setuid.
@@ -307,11 +307,23 @@ sub govern_process {
     my %args = @_;
     $self->{args} = \%args;
     if (defined $args{euid}) {
-        $args{euid} =~ /\A[0-9]+\z/ or die "euid has to be integer";
+        # coerce from username
+        unless ($args{euid} =~ /\A[0-9]+\z/) {
+            my @pw = getpwnam $args{euid};
+            $args{euid} = $pw[2] if @pw;
+        }
+        $args{euid} =~ /\A[0-9]+\z/
+            or die "euid ('$args{euid}') has to be integer";
     }
     if (defined $args{egid}) {
+        # coerce from groupname
+        unless ($args{egid} =~ /\A[0-9]+( [0-9]+)*\z/) {
+            my @gr = getgrnam $args{egid};
+            $args{egid} = $gr[2] if @gr;
+        }
         $args{egid} =~ /\A[0-9]+( [0-9]+)*\z/
-            or die "egid has to be integer or integers separated by space";
+            or die "egid ('$args{egid}') has to be integer or ".
+            "integers separated by space";
     }
 
     require Proc::Killfam if $args{killfam};
@@ -567,7 +579,7 @@ Proc::Govern - Run child process and govern its various aspects
 
 =head1 VERSION
 
-This document describes version 0.201 of Proc::Govern (from Perl distribution Proc-Govern), released on 2019-04-30.
+This document describes version 0.202 of Proc::Govern (from Perl distribution Proc-Govern), released on 2019-05-22.
 
 =head1 SYNOPSIS
 
@@ -753,7 +765,7 @@ Set EGID(s) of command process.
 
 Need to be root to be able to setuid.
 
-=item * B<euid> => I<uint>
+=item * B<euid> => I<unix::uid>
 
 Set EUID of command process.
 
@@ -827,7 +839,7 @@ Prevent screensaver from being activated.
 Can be set to C<exit> to silently exit when there is already a running instance.
 Otherwise, will print an error message C<< Program E<lt>NAMEE<gt> already running >>.
 
-=item * B<pid_dir> => I<str>
+=item * B<pid_dir> => I<dirname>
 
 Directory to put PID file in.
 
@@ -851,7 +863,7 @@ Implemented using L<Proc::PID::File>. You will also normally have to set
 C<pid_dir>, unless your script runs as root, in which case you can use the
 default C</var/run>.
 
-=item * B<timeout> => I<int>
+=item * B<timeout> => I<duration>
 
 Apply execution time limit, in seconds.
 
